@@ -1,5 +1,4 @@
 /**********************************************************************
- * $Id: cu_out_wkb.c 13242 2015-02-19 00:22:22Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.net
@@ -22,6 +21,7 @@
 ** Global variable to hold hex WKB strings
 */
 char *s;
+size_t s_size;
 
 /*
 ** The suite initialization function.
@@ -62,10 +62,19 @@ static void cu_wkb(char *wkt)
 {
 	LWGEOM *g = lwgeom_from_wkt(wkt, LW_PARSER_CHECK_NONE);
 	if ( s ) free(s);
-	s = (char*)lwgeom_to_wkb(g, WKB_HEX | WKB_XDR | WKB_EXTENDED, NULL);
+	s = (char*)lwgeom_to_wkb(g, WKB_HEX | WKB_XDR | WKB_EXTENDED, &s_size);
 	lwgeom_free(g);
 }
 
+static void cu_wkb_empty_point_check(char *hex)
+{
+	LWGEOM *g;
+	g = lwgeom_from_hexwkb(hex, LW_PARSER_CHECK_NONE);
+	CU_ASSERT(g != NULL);
+	CU_ASSERT(lwgeom_is_empty(g));
+	CU_ASSERT(g->type == POINTTYPE);
+	lwgeom_free(g);	
+}
 
 static void test_wkb_out_point(void)
 {
@@ -74,6 +83,21 @@ static void test_wkb_out_point(void)
 
 	cu_wkb("SRID=4;POINTM(1 1 1)");
 	CU_ASSERT_STRING_EQUAL(s,"0060000001000000043FF00000000000003FF00000000000003FF0000000000000");
+	
+	cu_wkb("POINT EMPTY");
+	cu_wkb_empty_point_check(s);
+	
+	cu_wkb("SRID=4326;POINT EMPTY");
+	cu_wkb_empty_point_check(s);
+
+	cu_wkb("POINT Z EMPTY");
+	cu_wkb_empty_point_check(s);
+
+	cu_wkb("POINT M EMPTY");
+	cu_wkb_empty_point_check(s);
+
+	cu_wkb("POINT ZM EMPTY");
+	cu_wkb_empty_point_check(s);
 }
 
 static void test_wkb_out_linestring(void)
@@ -116,8 +140,10 @@ static void test_wkb_out_multipoint(void)
 	CU_ASSERT_STRING_EQUAL(s,"00A000000400000004000000050080000001000000000000000000000000000000000000000000000000008000000100000000000000003FF0000000000000000000000000000000800000013FF00000000000003FF0000000000000000000000000000000800000013FF0000000000000000000000000000000000000000000000080000001000000000000000000000000000000000000000000000000");
 
 	cu_wkb("MULTIPOINT(0 0 0, 0.26794919243112270647255365849413 1 3)");
-	//printf("WKB: %s",s);
 	CU_ASSERT_STRING_EQUAL(s,"008000000400000002008000000100000000000000000000000000000000000000000000000000800000013FD126145E9ECD563FF00000000000004008000000000000");
+
+	cu_wkb("MULTIPOINT EMPTY");
+	CU_ASSERT_STRING_EQUAL(s,"000000000400000000");
 }
 
 static void test_wkb_out_multilinestring(void) {}
@@ -126,6 +152,9 @@ static void test_wkb_out_multipolygon(void)
 {
 	cu_wkb("SRID=14;MULTIPOLYGON(((0 0 0,0 1 0,1 1 0,1 0 0,0 0 0)),((-1 -1 0,-1 2 0,2 2 0,2 -1 0,-1 -1 0),(0 0 0,0 1 0,1 1 0,1 0 0,0 0 0)))");
 	CU_ASSERT_STRING_EQUAL(s,"00A00000060000000E000000020080000003000000010000000500000000000000000000000000000000000000000000000000000000000000003FF000000000000000000000000000003FF00000000000003FF000000000000000000000000000003FF00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000800000030000000200000005BFF0000000000000BFF00000000000000000000000000000BFF0000000000000400000000000000000000000000000004000000000000000400000000000000000000000000000004000000000000000BFF00000000000000000000000000000BFF0000000000000BFF000000000000000000000000000000000000500000000000000000000000000000000000000000000000000000000000000003FF000000000000000000000000000003FF00000000000003FF000000000000000000000000000003FF000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000");
+
+	cu_wkb("MULTIPOLYGON EMPTY");
+	CU_ASSERT_STRING_EQUAL(s,"000000000600000000");
 }
 
 static void test_wkb_out_collection(void)
@@ -135,6 +164,13 @@ static void test_wkb_out_collection(void)
 
 	cu_wkb("GEOMETRYCOLLECTION EMPTY");
 	CU_ASSERT_STRING_EQUAL(s,"000000000700000000");
+
+	cu_wkb("GEOMETRYCOLLECTION(LINESTRING EMPTY)");
+	CU_ASSERT_STRING_EQUAL(s,"000000000700000001000000000200000000");
+
+	cu_wkb("GEOMETRYCOLLECTION(LINESTRING EMPTY, MULTILINESTRING(EMPTY,EMPTY))");
+	// printf("%s\n",s );
+	CU_ASSERT_STRING_EQUAL(s,"000000000700000002000000000200000000000000000500000002000000000200000000000000000200000000");
 }
 
 static void test_wkb_out_circularstring(void) 
@@ -178,7 +214,7 @@ static void test_wkb_out_polyhedralsurface(void)
 void wkb_out_suite_setup(void);
 void wkb_out_suite_setup(void)
 {
-	CU_pSuite suite = CU_add_suite("WKB Output", init_wkb_out_suite, clean_wkb_out_suite);
+	CU_pSuite suite = CU_add_suite("wkb_output", init_wkb_out_suite, clean_wkb_out_suite);
 	PG_ADD_TEST(suite, test_wkb_out_point);
 	PG_ADD_TEST(suite, test_wkb_out_linestring);
 	PG_ADD_TEST(suite, test_wkb_out_polygon);
