@@ -1,5 +1,4 @@
 /**********************************************************************
- * $Id$
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.net
@@ -57,7 +56,7 @@ static void test_stringbuffer_aprintf(void)
 void stringbuffer_suite_setup(void);
 void stringbuffer_suite_setup(void)
 {
-	CU_pSuite suite = CU_add_suite("StringBuffer", NULL, NULL);
+	CU_pSuite suite = CU_add_suite("stringbuffer", NULL, NULL);
 	PG_ADD_TEST(suite, test_stringbuffer_append);
 	PG_ADD_TEST(suite, test_stringbuffer_aprintf);
 }
