@@ -3,7 +3,7 @@
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.net
  * Copyright 2001-2006 Refractions Research Inc.
- * Copyright 2010 Nicklas Avn
+ * Copyright 2010 Nicklas Avén
  * Copyright 2012 Paul Ramsey
  *
  * This is free software; you can redistribute and/or modify it under
@@ -18,11 +18,37 @@
 #include "lwgeom_log.h"
 
 
+
 /*------------------------------------------------------------------------------------------------------------
 Initializing functions
 The functions starting the distance-calculation processses
 --------------------------------------------------------------------------------------------------------------*/
 
+LWGEOM *
+lwgeom_closest_line(const LWGEOM *lw1, const LWGEOM *lw2)
+{
+  return lw_dist2d_distanceline(lw1, lw2, lw1->srid, DIST_MIN);
+}
+
+LWGEOM *
+lwgeom_furthest_line(const LWGEOM *lw1, const LWGEOM *lw2)
+{
+  return lw_dist2d_distanceline(lw1, lw2, lw1->srid, DIST_MAX);
+}
+
+LWGEOM *
+lwgeom_closest_point(const LWGEOM *lw1, const LWGEOM *lw2)
+{
+  return lw_dist2d_distancepoint(lw1, lw2, lw1->srid, DIST_MIN);  
+}
+
+LWGEOM *
+lwgeom_furthest_point(const LWGEOM *lw1, const LWGEOM *lw2)
+{
+  return lw_dist2d_distancepoint(lw1, lw2, lw1->srid, DIST_MAX);  
+}
+
+
 void
 lw_dist2d_distpts_init(DISTPTS *dl, int mode)
 {
@@ -32,20 +58,20 @@ lw_dist2d_distpts_init(DISTPTS *dl, int mode)
 	dl->mode = mode;
 	dl->tolerance = 0.0;
 	if ( mode == DIST_MIN )
-		dl->distance = MAXFLOAT;
+		dl->distance = FLT_MAX;
 	else
-		dl->distance = -1 * MAXFLOAT;
+		dl->distance = -1 * FLT_MAX;
 }
 
 /**
 Function initializing shortestline and longestline calculations.
 */
 LWGEOM *
-lw_dist2d_distanceline(LWGEOM *lw1, LWGEOM *lw2, int srid, int mode)
+lw_dist2d_distanceline(const LWGEOM *lw1, const LWGEOM *lw2, int srid, int mode)
 {
 	double x1,x2,y1,y2;
 
-	double initdistance = ( mode == DIST_MIN ? MAXFLOAT : -1.0);
+	double initdistance = ( mode == DIST_MIN ? FLT_MAX : -1.0);
 	DISTPTS thedl;
 	LWPOINT *lwpoints[2];
 	LWGEOM *result;
@@ -88,11 +114,11 @@ lw_dist2d_distanceline(LWGEOM *lw1, LWGEOM *lw2, int srid, int mode)
 Function initializing closestpoint calculations.
 */
 LWGEOM *
-lw_dist2d_distancepoint(LWGEOM *lw1, LWGEOM *lw2,int srid,int mode)
+lw_dist2d_distancepoint(const LWGEOM *lw1, const LWGEOM *lw2,int srid,int mode)
 {
 	double x,y;
 	DISTPTS thedl;
-	double initdistance = MAXFLOAT;
+	double initdistance = FLT_MAX;
 	LWGEOM *result;
 
 	thedl.mode = mode;
@@ -126,7 +152,7 @@ lw_dist2d_distancepoint(LWGEOM *lw1, LWGEOM *lw2,int srid,int mode)
 Function initialazing max distance calculation
 */
 double
-lwgeom_maxdistance2d(LWGEOM *lw1, LWGEOM *lw2)
+lwgeom_maxdistance2d(const LWGEOM *lw1, const LWGEOM *lw2)
 {
 	LWDEBUG(2, "lwgeom_maxdistance2d is called");
 
@@ -138,7 +164,7 @@ Function handling max distance calculations and dfyllywithin calculations.
 The difference is just the tolerance.
 */
 double
-lwgeom_maxdistance2d_tolerance(LWGEOM *lw1, LWGEOM *lw2, double tolerance)
+lwgeom_maxdistance2d_tolerance(const LWGEOM *lw1, const LWGEOM *lw2, double tolerance)
 {
 	/*double thedist;*/
 	DISTPTS thedl;
@@ -159,7 +185,7 @@ lwgeom_maxdistance2d_tolerance(LWGEOM *lw1, LWGEOM *lw2, double tolerance)
 	Function initialazing min distance calculation
 */
 double
-lwgeom_mindistance2d(LWGEOM *lw1, LWGEOM *lw2)
+lwgeom_mindistance2d(const LWGEOM *lw1, const LWGEOM *lw2)
 {
 	LWDEBUG(2, "lwgeom_mindistance2d is called");
 	return lwgeom_mindistance2d_tolerance( lw1, lw2, 0.0 );
@@ -170,12 +196,12 @@ lwgeom_mindistance2d(LWGEOM *lw1, LWGEOM *lw2)
 	The difference is just the tolerance.
 */
 double
-lwgeom_mindistance2d_tolerance(LWGEOM *lw1, LWGEOM *lw2, double tolerance)
+lwgeom_mindistance2d_tolerance(const LWGEOM *lw1, const LWGEOM *lw2, double tolerance)
 {
 	DISTPTS thedl;
 	LWDEBUG(2, "lwgeom_mindistance2d_tolerance is called");
 	thedl.mode = DIST_MIN;
-	thedl.distance= MAXFLOAT;
+	thedl.distance= FLT_MAX;
 	thedl.tolerance = tolerance;
 	if (lw_dist2d_comp( lw1,lw2,&thedl))
 	{
@@ -183,7 +209,7 @@ lwgeom_mindistance2d_tolerance(LWGEOM *lw1, LWGEOM *lw2, double tolerance)
 	}
 	/*should never get here. all cases ought to be error handled earlier*/
 	lwerror("Some unspecified error.");
-	return MAXFLOAT;
+	return FLT_MAX;
 }
 
 
@@ -202,7 +228,7 @@ Functions preparing geometries for distance-calculations
 	bboxes we will use anyway.
 */
 int
-lw_dist2d_comp(LWGEOM *lw1, LWGEOM *lw2, DISTPTS *dl)
+lw_dist2d_comp(const LWGEOM *lw1,const LWGEOM *lw2, DISTPTS *dl)
 {
 	LWDEBUG(2, "lw_dist2d_comp is called");
 
@@ -327,7 +353,7 @@ int lw_dist2d_recursive(const LWGEOM *lwg1, const LWGEOM *lwg2, DISTPTS *dl)
 
 
 int
-lw_dist2d_distribute_bruteforce(LWGEOM *lwg1, LWGEOM *lwg2, DISTPTS *dl)
+lw_dist2d_distribute_bruteforce(const LWGEOM *lwg1,const LWGEOM *lwg2, DISTPTS *dl)
 {
 
 	int	t1 = lwg1->type;
