@@ -1,10 +1,9 @@
 
 /**********************************************************************
- * $Id: measures.h 4715 2009-11-01 17:58:42Z nicklas $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.net
- * Copyright 2010 Nicklas Avn
+ * Copyright 2010 Nicklas Avén
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU General Public Licence. See the COPYING file.
@@ -13,10 +12,12 @@
 
 #include "liblwgeom_internal.h"
 
+/* for the measure functions*/
+#define DIST_MAX		-1
+#define DIST_MIN		1
 
-/**
-
-Structure used in distance-calculations
+/** 
+* Structure used in distance-calculations
 */
 typedef struct
 {
@@ -30,18 +31,18 @@ typedef struct
 
 typedef struct
 {
-	double	themeasure;	/*a value calculated to compare distances*/
-	int		pnr;	/*pointnumber. the ordernumber of the point*/
+	double themeasure;	/*a value calculated to compare distances*/
+	int pnr;	/*pointnumber. the ordernumber of the point*/
 } LISTSTRUCT;
 
 
 /*
 * Preprocessing functions
 */
-int lw_dist2d_comp(LWGEOM *lw1, LWGEOM *lw2, DISTPTS *dl);
-int lw_dist2d_distribute_bruteforce(LWGEOM *lwg1, LWGEOM *lwg2, DISTPTS *dl);
+int lw_dist2d_comp(const LWGEOM *lw1, const LWGEOM *lw2, DISTPTS *dl);
+int lw_dist2d_distribute_bruteforce(const LWGEOM *lwg1, const LWGEOM *lwg2, DISTPTS *dl);
 int lw_dist2d_recursive(const LWGEOM *lwg1, const LWGEOM *lwg2, DISTPTS *dl);
-int lw_dist2d_check_overlap(LWGEOM *lwg1,LWGEOM *lwg2);
+int lw_dist2d_check_overlap(LWGEOM *lwg1, LWGEOM *lwg2);
 int lw_dist2d_distribute_fast(LWGEOM *lwg1, LWGEOM *lwg2, DISTPTS *dl);
 
 /*
@@ -93,3 +94,10 @@ void lw_dist2d_distpts_init(DISTPTS *dl, int mode);
 */
 double lw_arc_length(const POINT2D *A1, const POINT2D *A2, const POINT2D *A3);
 
+/*
+* Geometry returning functions
+*/
+LWGEOM* lw_dist2d_distancepoint(const LWGEOM *lw1, const LWGEOM *lw2, int srid, int mode);
+LWGEOM* lw_dist2d_distanceline(const LWGEOM *lw1, const LWGEOM *lw2, int srid, int mode);
+
+
