@@ -1,5 +1,4 @@
 /**********************************************************************
- * $Id: pgsql2shp.c 5450 2010-03-22 19:38:14Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://www.postgis.org
@@ -833,16 +832,18 @@ projFileCreate(SHPDUMPERSTATE *state)
 				{
 					return 0;
 				}
-				result = fputs (srtext,fp);
-        LWDEBUGF(3, "\n result %d proj SRText is %s .\n", result, srtext);
-        if (result == EOF)
-        {
-            fclose( fp );
-            free( pszFullname );
-            PQclear(res);
-            free(query);
-            return 0;
-        }
+				{
+				    result = fputs (srtext,fp);
+                    LWDEBUGF(3, "\n result %d proj SRText is %s .\n", result, srtext);
+                    if (result == EOF)
+                    {
+                        fclose( fp );
+                        free( pszFullname );
+                        PQclear(res);
+                        free(query);
+                        return 0;
+                    }
+				}
 				fclose( fp );
 				free( pszFullname );
 			}
@@ -1141,100 +1142,6 @@ set_dumper_config_defaults(SHPDUMPERCONFIG *config)
 	config->column_map_filename = NULL;
 }
 
-/**
- * Read the content of filename into a symbol map stored
- * at state->column_map_filename.
- *
- * The content of the file is lines of two names separated by
- * white space and no trailing or leading space:
- *
- *    COLUMNNAME DBFFIELD1
- *    AVERYLONGCOLUMNNAME DBFFIELD2
- *
- *    etc.
- *
- * It is the reponsibility of the caller to reclaim the allocated space
- * as follows:
- *
- * free(state->column_map_pgfieldnames[]) to free the column names
- * free(state->column_map_dbffieldnames[]) to free the dbf field names
- *
- * @param state : container of state->column_map where the malloc'd
- *                symbol map will be stored.
- */
-static int
-read_column_map(SHPDUMPERSTATE *state)
-{
-	FILE *fptr;
-	char linebuffer[1024];
-	char *tmpstr, *tmpptr;
-	int curmapsize, fieldnamesize;
-	
-	/* Read column map file and load the column_map_dbffieldnames and column_map_pgfieldnames
-	   arrays */
-	fptr = fopen(state->config->column_map_filename, "r");
-	if (!fptr)
-	{
-		/* Return an error */
-		snprintf(state->message, SHPDUMPERMSGLEN, _("ERROR: Unable to open column map file %s"), state->config->column_map_filename);
-		return SHPDUMPERERR;
-	}
-	
-	/* First count how many columns we have... */
-	while (fgets(linebuffer, 1024, fptr) != NULL)
-		state->column_map_size++;
-	
-	/* Now we know the final size, allocate the arrays and load the data */
-	fseek(fptr, 0, SEEK_SET);
-	state->column_map_pgfieldnames = (char **)malloc(sizeof(char *) * state->column_map_size);
-	state->column_map_dbffieldnames = (char **)malloc(sizeof(char *) * state->column_map_size);
-	
-	/* Read in a line at a time... */
-	curmapsize = 0;
-	while (fgets(linebuffer, 1024, fptr) != NULL)
-	{
-		/* Split into two separate strings - pgfieldname followed by dbffieldname */
-
-		/* First locate end of first column (pgfieldname) */
- 		for (tmpptr = tmpstr = linebuffer; *tmpptr != '\t' && *tmpptr != '\n' && *tmpptr != ' ' && *tmpptr != '\0'; tmpptr++);		
-		fieldnamesize = tmpptr - tmpstr;
-
-		/* Allocate memory and copy the string ensuring it is terminated */
-		state->column_map_pgfieldnames[curmapsize] = malloc(fieldnamesize + 1);
-		strncpy(state->column_map_pgfieldnames[curmapsize], tmpstr, fieldnamesize);
-		state->column_map_pgfieldnames[curmapsize][fieldnamesize] = '\0';
-		
-		/* Now swallow up any whitespace */
-		for (tmpstr = tmpptr; *tmpptr == '\t' || *tmpptr == '\n' || *tmpptr == ' '; tmpptr++) {
-            ; /* Do nothing */
-        }
-
-		/* Finally locate end of second column (dbffieldname) */
- 		for (tmpstr = tmpptr; *tmpptr != '\t' && *tmpptr != '\n' && *tmpptr != ' ' && *tmpptr != '\0'; tmpptr++);		
-		fieldnamesize = tmpptr - tmpstr;
-		
-		/* Allocate memory and copy the string ensuring it is terminated */
-		state->column_map_dbffieldnames[curmapsize] = malloc(fieldnamesize + 1);
-		strncpy(state->column_map_dbffieldnames[curmapsize], tmpstr, fieldnamesize);
-		state->column_map_dbffieldnames[curmapsize][fieldnamesize] = '\0';
-		
-		/* Error out if the dbffieldname is > 10 chars */
-		if (strlen(state->column_map_dbffieldnames[curmapsize]) > 10)
-		{
-			snprintf(state->message, SHPDUMPERMSGLEN, _("ERROR: column map file specifies a DBF field name \"%s\" which is longer than 10 characters"), state->column_map_dbffieldnames[curmapsize]);
-			return SHPDUMPERERR;
-		}
-		
-		curmapsize++;
-	}
-
-	fclose(fptr);
-
-	/* Done; return success */
-	return SHPDUMPEROK;
-}
-
-
 /* Create a new shapefile state object */
 SHPDUMPERSTATE *
 ShpDumperCreate(SHPDUMPERCONFIG *config)
@@ -1258,10 +1165,8 @@ ShpDumperCreate(SHPDUMPERCONFIG *config)
 	state->dbffieldnames = NULL;
 	state->dbffieldtypes = NULL;
 	state->pgfieldnames = NULL;
-	state->column_map_pgfieldnames = NULL;
-	state->column_map_dbffieldnames = NULL;
-	state->column_map_size = 0;
 	state->big_endian = is_bigendian();
+	colmap_init(&state->column_map);
 	
 	return state;
 }
@@ -1312,6 +1217,11 @@ ShpDumperGetConnectionStringFromConn(SHPCONNECTIONCONFIG *conn)
 		strcat(connstring, conn->database);
 	}
 
+	if ( ! getenv("PGCLIENTENCODING") )
+	{
+		strcat(connstring, " client_encoding=UTF8");
+	}
+
 	return connstring;
 }
 
@@ -1427,15 +1337,15 @@ ShpDumperOpenTable(SHPDUMPERSTATE *state)
 	/* Open the column map if one was specified */
 	if (state->config->column_map_filename)
 	{
-		ret = read_column_map(state);
-		if (ret != SHPDUMPEROK)
-			return SHPDUMPERERR;
+		ret = colmap_read(state->config->column_map_filename,
+		                  &state->column_map, state->message, SHPDUMPERMSGLEN);
+		if (!ret) return SHPDUMPERERR;
 	}
 		
 	/* If a user-defined query has been specified, create and point the state to our new table */
 	if (state->config->usrquery)
 	{
-		state->table = malloc(20 + 20);		// string + max long precision
+		state->table = malloc(20 + 20);		/* string + max long precision */
 		sprintf(state->table, "__pgsql2shp%lu_tmp_table", (long)getpid());
 
 		query = malloc(32 + strlen(state->table) + strlen(state->config->usrquery));
@@ -1512,8 +1422,19 @@ ShpDumperOpenTable(SHPDUMPERSTATE *state)
 	else
 		state->shp_file = state->table;
 
-	/* Create the dbf file */
-	state->dbf = DBFCreate(state->shp_file);
+	/* Create the dbf file: */
+	/* If there's a user-specified encoding hanging around, try and use that. */
+	/* Otherwise, just use UTF-8 encoding, since that's usually our client encoding. */
+	if ( getenv("PGCLIENTENCODING") )
+	{
+		char *codepage = encoding2codepage(getenv("PGCLIENTENCODING"));
+		state->dbf = DBFCreateEx(state->shp_file, codepage);
+	}
+	else
+	{
+		state->dbf = DBFCreateEx(state->shp_file, "UTF-8");
+	}
+		
 	if (!state->dbf)
 	{
 		snprintf(state->message, SHPDUMPERMSGLEN, _("Could not create dbf file %s"), state->shp_file);
@@ -1602,17 +1523,15 @@ ShpDumperOpenTable(SHPDUMPERSTATE *state)
 		strncpy(dbffieldname, ptr, 10);
 		dbffieldname[10] = '\0';
 
-		/* If a column map file has been passed in, use this to create the dbf field name from
-		   the PostgreSQL column name */
-		if (state->column_map_size > 0)
+		/* If a column map file has been passed in,
+		 * use this to create the dbf field name from
+		 * the PostgreSQL column name */
 		{
-			for (j = 0; j < state->column_map_size; j++)
-			{
-				if (!strcasecmp(state->column_map_pgfieldnames[j], dbffieldname))
-				{
-					strncpy(dbffieldname, state->column_map_dbffieldnames[j], 10);
-					dbffieldname[10] = '\0';
-				}
+		  const char *mapped = colmap_dbf_by_pg(&state->column_map, dbffieldname);
+		  if (mapped)
+		  {
+			  strncpy(dbffieldname, mapped, 10);
+			  dbffieldname[10] = '\0';
 			}
 		}
 			
@@ -2291,20 +2210,7 @@ ShpDumperDestroy(SHPDUMPERSTATE *state)
 			free(state->pgfieldnames);
 
 		/* Free any column map fieldnames if specified */
-		if (state->column_map_size > 0)
-		{
-			for (i = 0; i < state->column_map_size; i++)
-			{
-				if (state->column_map_pgfieldnames[i])
-					free(state->column_map_pgfieldnames[i]);
-				
-				if (state->column_map_dbffieldnames[i])
-					free(state->column_map_dbffieldnames[i]);
-			}
-			
-			free(state->column_map_pgfieldnames);
-			free(state->column_map_dbffieldnames);
-		}
+		colmap_clean(&state->column_map);
 		
 		/* Free other names */
 		if (state->table)
