@@ -1,5 +1,4 @@
 -----------------------------------------------------------------------
--- $Id$
 --
 -- Copyright (c) 2010 Pierre Racine <pierre.racine@sbf.ulaval.ca>
 --
@@ -15,7 +14,7 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with this program; if not, write to the Free Software Foundation,
--- Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+-- Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 -----------------------------------------------------------------------
 
 -----------------------------------------------------------------------
@@ -183,7 +182,6 @@ SELECT * FROM ST_BandMetadata(
 SELECT (ST_DumpAsPolygons(newrast,3)).val As b3val FROM (SELECT ST_AddBand(NULL, array_agg(rast)) AS newrast FROM (SELECT ST_AsRaster(ST_Buffer(ST_Point(10,10), 34),200,200, '8BUI',i*30) As rast FROM generate_series(1,3) As i ) As foo ) As foofoo;
 
 -- out-db variants
-/*
 SELECT
 	1,
 	bandnum,
@@ -224,4 +222,38 @@ SELECT
 		ELSE NULL
 	END
 FROM ST_BandMetadata((SELECT rast FROM raster_outdb_template WHERE rid = 4), ARRAY[]::int[]);
-*/
+
+-- #3020
+SET postgis.gdal_enabled_drivers = 'GTiff';
+SET postgis.enable_outdb_rasters = true;
+WITH foo AS (
+	SELECT
+			path
+	FROM ST_BandMetadata(
+		(SELECT rast FROM raster_outdb_template WHERE rid = 1),
+	 	ARRAY[]::int[]
+	)
+	LIMIT 1
+), raster as (
+SELECT
+	ST_AddBand(
+		ST_MakeEmptyRaster(90, 90, 0., 0., 1, -1, 0, 0, 0),
+		1, foo.path, NULL::int[]
+	) AS rast
+FROM foo
+)
+SELECT
+	ST_Value(rast, 1, 1)
+FROM raster
+UNION ALL
+SELECT
+	ST_Value(rast, 6, 45)
+FROM raster
+UNION ALL
+SELECT
+	ST_Value(rast, 90, 50)
+FROM raster
+UNION ALL
+SELECT
+	ST_Value(rast, 100, 100)
+FROM raster
